unit RTOSDemoImpl;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, ActiveX, AxCtrls, RTOSDemoProj_TLB, StdCtrls, NertosLib_TLB,
  ComCtrls, ExtCtrls, RTOSDemoDefs, ComObj;

type
  TRTOSDemoFactory = class(TActiveFormFactory)
  public
    procedure UpdateRegistry(Register : boolean); override;
  end; // TRTOSDemoFactory

  TRTOSDemoProj = class(TActiveForm, IRTOSDemo, INertos)
    RTOSDemoPC: TPageControl;
    TasksTS: TTabSheet;
    TimersTS: TTabSheet;
    SemaphoresTS: TTabSheet;
    GraphTS: TTabSheet;
    TasksM: TMemo;
    TimersM: TMemo;
    SemaphoresM: TMemo;
    ControlP: TPanel;
    GoB: TButton;
    BreakB: TButton;
    EmulatorL: TLabel;
    StatusL: TLabel;
    TStartB: TButton;
    TStopB: TButton;
    TStatusL: TLabel;
    MsgL: TLabel;
    LoggingTS: TTabSheet;
    LoggingP: TPanel;
    LoggingCB: TCheckBox;
    LoggingM: TMemo;
    ClearLogB: TButton;
    procedure GoBClick(Sender: TObject);
    procedure BreakBClick(Sender: TObject);
    procedure TStartBClick(Sender: TObject);
    procedure TStopBClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure LoggingCBClick(Sender: TObject);
    procedure ClearLogBClick(Sender: TObject);
  private
    { Private declarations }
    FEvents: IRTOSDemoEvents;
    FNertosEvents : INertosEvents;
    procedure ActivateEvent(Sender: TObject);
    procedure ClickEvent(Sender: TObject);
    procedure CreateEvent(Sender: TObject);
    procedure DblClickEvent(Sender: TObject);
    procedure DeactivateEvent(Sender: TObject);
    procedure DestroyEvent(Sender: TObject);
    procedure KeyPressEvent(Sender: TObject; var Key: Char);
    procedure PaintEvent(Sender: TObject);
  protected
    { Protected declarations }
    procedure DefinePropertyPages(DefinePropertyPage: TDefinePropertyPage); override;
    procedure EventSinkChanged(const EventSink: IUnknown); override;
    function Get_Active: WordBool; safecall;
    function Get_AutoScroll: WordBool; safecall;
    function Get_AutoSize: WordBool; safecall;
    function Get_AxBorderStyle: TxActiveFormBorderStyle; safecall;
    function Get_BiDiMode: TxBiDiMode; safecall;
    function Get_Caption: WideString; safecall;
    function Get_Color: OLE_COLOR; safecall;
    function Get_Cursor: Smallint; safecall;
    function Get_DoubleBuffered: WordBool; safecall;
    function Get_DropTarget: WordBool; safecall;
    function Get_Enabled: WordBool; safecall;
    function Get_Font: IFontDisp; safecall;
    function Get_HelpFile: WideString; safecall;
    function Get_KeyPreview: WordBool; safecall;
    function Get_PixelsPerInch: Integer; safecall;
    function Get_PrintScale: TxPrintScale; safecall;
    function Get_Scaled: WordBool; safecall;
    function Get_Visible: WordBool; safecall;
    procedure _Set_Font(const Value: IFontDisp); safecall;
    procedure Set_AutoScroll(Value: WordBool); safecall;
    procedure Set_AutoSize(Value: WordBool); safecall;
    procedure Set_AxBorderStyle(Value: TxActiveFormBorderStyle); safecall;
    procedure Set_BiDiMode(Value: TxBiDiMode); safecall;
    procedure Set_Caption(const Value: WideString); safecall;
    procedure Set_Color(Value: OLE_COLOR); safecall;
    procedure Set_Cursor(Value: Smallint); safecall;
    procedure Set_DoubleBuffered(Value: WordBool); safecall;
    procedure Set_DropTarget(Value: WordBool); safecall;
    procedure Set_Enabled(Value: WordBool); safecall;
    procedure Set_Font(var Value: IFontDisp); safecall;
    procedure Set_HelpFile(const Value: WideString); safecall;
    procedure Set_KeyPreview(Value: WordBool); safecall;
    procedure Set_PixelsPerInch(Value: Integer); safecall;
    procedure Set_PrintScale(Value: TxPrintScale); safecall;
    procedure Set_Scaled(Value: WordBool); safecall;
    procedure Set_Visible(Value: WordBool); safecall;
    procedure ConnectEvents(const ine: INertosEvents); safecall;
    procedure Endian(LEndian: Smallint); safecall;
    procedure ProgramLoaded; safecall;
    procedure ProgramReset; safecall;
    procedure ReadMemoryTest(memtype: Smallint; address: Integer;
      size: Integer; dest: Integer); safecall;
    procedure Init(const initstring: WideString); safecall;
    procedure Terminate; safecall;
    procedure Started; safecall;
    procedure Stopped(pc: Integer); safecall;
    procedure AboutBox; safecall;
    procedure TraceStarted; safecall;
    procedure TraceStopped; safecall;
  public
    { Public declarations }
    RTOSInit : boolean;
    EmulRunning : boolean;
    IsLogging : boolean;
    AppAddr : DWORD;
    App : TApp16;
    Task : TTask16;
    Timer : TTimer16;
    Sema : TSema16;

    procedure Initialize; override;
    procedure InitRTOS;
    procedure UpdateAll;
    procedure UpdateApp;
    function UpdateTasks : boolean;
    function UpdateTimers : boolean;
    function UpdateSemaphores : boolean;
    function GetStr16(nameptr16 : integer) : string;
    procedure Log(str : string);
  end; // TRTOSDemoProj

implementation

uses
  ComServ, RTOSDemoAbout;

const
  MAXMAXTASKS = 100;
  MAXMAXSEMAS = 100;
  MAXMAXTIMERS = 100;
  IDLETASKNAME = 'Idle';
  EMULGOMSG = 'Emulator Running';
  EMULBREAKMSG = 'Emulator Stopped';
  TRACESTARTMSG = 'Trace Started';
  TRACESTOPMSG = 'Trace Stopped';


{$R *.DFM}

{ TRTOSDemoFactory }

procedure TRTOSDemoFactory.UpdateRegistry(Register : boolean);

var
  ClassKey : string;

begin // TRTOSDemoFactory.UpdateRegistry
  ClassKey := 'CLSID\' + GUIDToString(ClassID);
  if Register then begin
    inherited UpdateRegistry(Register);
    CreateRegKey(ClassKey + '\' + RTOSKEYNAME, '', '');
    end // then
  else begin
    DeleteRegKey(ClassKey + '\' + RTOSKEYNAME);
    inherited UpdateRegistry(Register);
  end; // if
end; // TRTOSDemoFactory.UpdateRegistry


{ TRTOSDemo }

procedure TRTOSDemoProj.FormCreate(Sender: TObject);

begin // TRTOSDemoProj.FormCreate
  RTOSDemoPC.ActivePage := TasksTS;
  RTOSInit := false;
  EmulRunning := false;
  IsLogging := false;
end; // TRTOSDemoProj.FormCreate


procedure TRTOSDemoProj.InitRTOS;

var
  str1, str2 : widestring;

begin // TRTOSDemo.InitRTOS
  FNertosEvents.ExecCmd('View_Evaluate "App"', str1);
  FNertosEvents.ExecCmd('Wnd_GetErr', str2);
  if StrToInt(str2) = 0 then begin
    MsgL.Caption := '';
    RTOSInit := true;
    try
      AppAddr := StrToInt64(str1);
    except
      RTOSInit := false;
      MsgL.Caption := 'Conversion error!';
    end; // try
    end // then
  else begin
    RTOSInit := false;
    MsgL.Caption := 'Not Initialized!';
  end; // if
end; // TRTOSDemo.InitRTOS


procedure TRTOSDemoProj.UpdateAll;

begin // TRTOSDemo.UpdateAll
  if RTOSInit then begin
    UpdateApp;
    if not UpdateTasks
      or not UpdateTimers
      or not UpdateSemaphores then begin
      RTOSInit := false;
      TasksM.Clear;
      TimersM.Clear;
      SemaphoresM.Clear;
      LoggingCB.Checked := IsLogging;
      if IsLogging then begin
        LoggingM.Clear;
      end; // if
    end; // if
  end; // if
end; // TRTOSDemo.UpdateAll


procedure TRTOSDemoProj.UpdateApp;

begin // TRTOSDemo.UpdateApp
  FNertosEvents.ReadMemory(0, AppAddr, SizeOf(App), Integer(@App));
end; // TRTOSDemo.UpdateApp


function TRTOSDemoProj.GetStr16(nameptr16 : integer) : string;

const
  MAXCHARINDEX = 99;

var
  nma : array[0 .. MAXCHARINDEX] of char;
  nm : string;

begin // TRTOSDemo.GetStr16
  if nameptr16 = 0 then begin // If null pointer
    nm := '<null name pointer>';
    end // then
  else begin
    FNertosEvents.ReadMemory(0, nameptr16, SizeOf(nma),
      Integer(@nma[0]));
    nma[MAXCHARINDEX] := char(0); // Force the string to end
    nm := nma;
    if nm = '' then begin // If null string
      nm := '<no name>';
    end; // if
  end; // if
  Result := nm;
end; // TRTOSDemo.GetStr16


function TRTOSDemoProj.UpdateTasks : boolean;

var
  res : boolean;
  index : integer;
  str : string;


begin // TRTOSDemo.UpdateTasks
  res := true; // Start out Good
  if App.MaxTasks > MAXMAXTASKS then begin
    res := false;
    MsgL.Caption := 'MaxTasks too large!';
    end // then
  else begin
    TasksM.Clear;
    index := 0;
    while res and (index < App.MaxTasks) do begin
      if App.TaskArray[index].Handle <> 0 then begin
        str := GetStr16(App.TaskArray[index].Name);
        if (index = 0) and (str <> IDLETASKNAME) then begin
          res := false;
          MsgL.Caption := 'Incorrect Idle Task!';
          end // then
        else begin
          str := str + ' - '
            + TaskStateName[TTaskState(App.TaskArray[index].State)];
          if App.TaskArray[index].Timer <> 0 then begin
            FNertosEvents.ReadMemory(0, App.TaskArray[index].Timer,
              SizeOf(Timer), Integer(@Timer));
            str := str + ', Timer: ' + GetStr16(Timer.Name);
          end; // if
          if App.TaskArray[index].Semaphore <> 0 then begin
            FNertosEvents.ReadMemory(0, App.TaskArray[index].Semaphore,
              SizeOf(Sema), Integer(@Sema));
            str := str + ', Semaphore: ' + GetStr16(Sema.Name);
          end; // if
          TasksM.Lines.Append(str);
        end; // if
      end; // if
      inc(index);
    end; // while
  end; // if
  Result := res;
end; // TRTOSDemo.UpdateTasks


function TRTOSDemoProj.UpdateTimers : boolean;

var
  res : boolean;
  index : integer;
  str : string;

begin // TRTOSDemo.UpdateTimers
  res := true; // Start out Good
  if App.MaxTimers > MAXMAXTIMERS then begin
    res := false;
    MsgL.Caption := 'MaxTimers too large!';
    end // then
  else begin
    TimersM.Clear;
    for index := 0 to App.MaxTimers - 1 do begin
      if App.TimerArray[index].Handle <> 0 then begin
        str := GetStr16(App.TimerArray[index].Name)
          + ' - '
          + TimerStateName[TTimerState(App.TimerArray[index].State)]
          + ', ' + IntToStr(App.TimerArray[index].Cnt) + ' ['
          + IntToStr(App.TimerArray[index].Value) + ']';
        if App.TimerArray[index].Task <> 0 then begin
          FNertosEvents.ReadMemory(0, App.TimerArray[index].Task,
            SizeOf(Task), Integer(@Task));
          str := str + ', Task: ' + GetStr16(Task.Name);
        end; // if
        TimersM.Lines.Append(str);
      end; // if
    end; // for
  end; // if
  Result := res;
end; // TRTOSDemo.UpdateTimers


function TRTOSDemoProj.UpdateSemaphores : boolean;

var
  res : boolean;
  index, index2, nm : integer;
  str : string;

begin // TRTOSDemo.UpdateSemaphores
  res := true; // Start out Good
  if App.MaxSemas > MAXMAXSEMAS then begin
    res := false;
    MsgL.Caption := 'MaxSemas too large!';
    end // then
  else begin
    SemaphoresM.Clear;
    for index := 0 to App.MaxSemas - 1 do begin
      if App.SemaArray[index].Handle <> 0 then begin
        str := GetStr16(App.SemaArray[index].Name) + ', '
          + IntToStr(App.SemaArray[index].Value) + ' ['
          + IntToStr(App.SemaArray[index].MaxValue) + ']';
        for index2 := 0 to MAXTASKS - 1 do begin
          if App.SemaArray[index].Queue[index2] <> 0 then begin
            FNertosEvents.ReadMemory(0,
              App.SemaArray[index].Queue[index2], SizeOf(nm),
              Integer(@nm));
            str := str + ', ' + GetStr16(nm);
          end; // if
        end; // for
        SemaphoresM.Lines.Append(str);
      end; // if
    end; // for
  end; // if
  Result := res;
end; // TRTOSDemo.UpdateSemaphores


procedure TRTOSDemoProj.Log(str : string);

var
  dtstr : string;

begin // TRTOSDemoProj.Log
  if IsLogging then begin
    DateTimeToString(dtstr, 'hh:nn:ss "on" mm/dd/yyyy', Now);
    LoggingM.Lines.Append(str + ' (' + dtstr + ')');
  end; // if
end; // TRTOSDemoProj.Log


procedure TRTOSDemoProj.ConnectEvents(const ine: INertosEvents);

begin // TRTOSDemo.ConnectEvents
  Log('=> ConnectEvents');
  FNertosEvents := ine;
end; // TRTOSDemo.ConnectEvents


procedure TRTOSDemoProj.Endian(LEndian: Smallint);

begin // TRTOSDemo.Endian
  Log('=> Endian');
end; // TRTOSDemo.Endian


procedure TRTOSDemoProj.ProgramLoaded;

begin // TRTOSDemo.ProgramLoaded
  Log('=> ProgramLoaded');
  InitRTOS;
  UpdateAll;
end; // TRTOSDemo.ProgramLoaded


procedure TRTOSDemoProj.ProgramReset;

begin // TRTOSDemo.ProgramReset
  Log('=> ProgramReset');
  InitRTOS;
  UpdateAll;
end; // TRTOSDemo.ProgramReset


procedure TRTOSDemoProj.ReadMemoryTest(memtype: Smallint; address: Integer;
  size: Integer; dest: Integer);

begin // TRTOSDemo.ReadMemoryTest
  Log('=> ReadMemoryTest');
end; // TRTOSDemo.ReadMemoryTest


procedure TRTOSDemoProj.Init(const initstring: WideString);

begin // TRTOSDemo.Init
  Log('=> Init');
  EmulatorL.Caption := initstring;
  StatusL.Caption := EMULBREAKMSG;
  TStatusL.Caption := TRACESTOPMSG;
  InitRTOS;
  UpdateAll;
end; // TRTOSDemo.Init


procedure TRTOSDemoProj.Terminate;

begin // TRTOSDemo.Terminate
  Log('=> Terminate');
  MsgL.Caption := '';
end; // TRTOSDemo.Terminate


procedure TRTOSDemoProj.Started;

begin // TRTOSDemo.Started
  Log('=> Started');
  StatusL.Caption := EMULGOMSG;
  EmulRunning := true;
end; // TRTOSDemo.Started


procedure TRTOSDemoProj.Stopped(pc: Integer);

begin // TRTOSDemo.Stopped
  Log('=> Stopped');
  EmulRunning := false;
  StatusL.Caption := EMULBREAKMSG + ' at: ' + IntToHex(pc, 4) + 'H';
  InitRTOS;
  UpdateAll;
end; // TRTOSDemo.Stopped


procedure TRTOSDemoProj.AboutBox;

begin // TRTOSDemo.AboutBox
  Log('=> AboutBox');
  AboutBoxDlg := TAboutBox.Create(Application);
  AboutBoxDlg.ShowModal;
  AboutBoxDlg.Free;
end; // TRTOSDemo.AboutBox


procedure TRTOSDemoProj.TraceStarted;

begin // TRTOSDemo.TraceStarted
  Log('=> TraceStarted');
  TStatusL.Caption := TRACESTARTMSG;
end; // TRTOSDemo.TraceStarted


procedure TRTOSDemoProj.TraceStopped;

begin // TRTOSDemo.TraceStopped
  Log('=> TraceStopped');
  TStatusL.Caption := TRACESTOPMSG;
end; // TRTOSDemo.TraceStopped


procedure TRTOSDemoProj.DefinePropertyPages(DefinePropertyPage: TDefinePropertyPage);

begin // TRTOSDemoProj.DefinePropertyPages
  { Define property pages here.  Property pages are defined by calling
    DefinePropertyPage with the class id of the page.  For example,
      DefinePropertyPage(Class_RTOSDemoPage); }
end; // TRTOSDemoProj.DefinePropertyPages


procedure TRTOSDemoProj.EventSinkChanged(const EventSink: IUnknown);

begin // TRTOSDemoProj.EventSinkChanged
  FEvents := EventSink as IRTOSDemoEvents;
end; // TRTOSDemoProj.EventSinkChanged


procedure TRTOSDemoProj.Initialize;

begin // TRTOSDemoProj.Initialize
  inherited Initialize;
  OnActivate := ActivateEvent;
  OnClick := ClickEvent;
  OnCreate := CreateEvent;
  OnDblClick := DblClickEvent;
  OnDeactivate := DeactivateEvent;
  OnDestroy := DestroyEvent;
  OnKeyPress := KeyPressEvent;
  OnPaint := PaintEvent;
end; // TRTOSDemoProj.Initialize


function TRTOSDemoProj.Get_Active: WordBool;

begin // TRTOSDemoProj.Get_Active
  Result := Active;
end; // TRTOSDemoProj.Get_Active


function TRTOSDemoProj.Get_AutoScroll: WordBool;

begin // TRTOSDemoProj.Get_AutoScroll
  Result := AutoScroll;
end; // TRTOSDemoProj.Get_AutoScroll


function TRTOSDemoProj.Get_AutoSize: WordBool;

begin // TRTOSDemoProj.Get_AutoSize
  Result := AutoSize;
end; // TRTOSDemoProj.Get_AutoSize


function TRTOSDemoProj.Get_AxBorderStyle: TxActiveFormBorderStyle;

begin // TRTOSDemoProj.Get_AxBorderStyle
  Result := Ord(AxBorderStyle);
end; // TRTOSDemoProj.Get_AxBorderStyle


function TRTOSDemoProj.Get_BiDiMode: TxBiDiMode;

begin // TRTOSDemoProj.Get_BiDiMode
  Result := Ord(BiDiMode);
end; // TRTOSDemoProj.Get_BiDiMode


function TRTOSDemoProj.Get_Caption: WideString;

begin // TRTOSDemoProj.Get_Caption
  Result := WideString(Caption);
end; // TRTOSDemoProj.Get_Caption


function TRTOSDemoProj.Get_Color: OLE_COLOR;

begin // TRTOSDemoProj.Get_Color
  Result := OLE_COLOR(Color);
end; // TRTOSDemoProj.Get_Color


function TRTOSDemoProj.Get_Cursor: Smallint;

begin // TRTOSDemoProj.Get_Cursor
  Result := Smallint(Cursor);
end; // TRTOSDemoProj.Get_Cursor


function TRTOSDemoProj.Get_DoubleBuffered: WordBool;

begin // TRTOSDemoProj.Get_DoubleBuffered
  Result := DoubleBuffered;
end; // TRTOSDemoProj.Get_DoubleBuffered


function TRTOSDemoProj.Get_DropTarget: WordBool;

begin // TRTOSDemoProj.Get_DropTarget
  Result := DropTarget;
end; // TRTOSDemoProj.Get_DropTarget


function TRTOSDemoProj.Get_Enabled: WordBool;

begin // TRTOSDemoProj.Get_Enabled
  Result := Enabled;
end; // TRTOSDemoProj.Get_Enabled


function TRTOSDemoProj.Get_Font: IFontDisp;

begin // TRTOSDemoProj.Get_Font
  GetOleFont(Font, Result);
end; // TRTOSDemoProj.Get_Font


function TRTOSDemoProj.Get_HelpFile: WideString;

begin // TRTOSDemoProj.Get_HelpFile
  Result := WideString(HelpFile);
end; // TRTOSDemoProj.Get_HelpFile


function TRTOSDemoProj.Get_KeyPreview: WordBool;

begin // TRTOSDemoProj.Get_KeyPreview
  Result := KeyPreview;
end; // TRTOSDemoProj.Get_KeyPreview


function TRTOSDemoProj.Get_PixelsPerInch: Integer;

begin // TRTOSDemoProj.Get_PixelsPerInch
  Result := PixelsPerInch;
end; // TRTOSDemoProj.Get_PixelsPerInch


function TRTOSDemoProj.Get_PrintScale: TxPrintScale;

begin // TRTOSDemoProj.Get_PrintScale
  Result := Ord(PrintScale);
end; // TRTOSDemoProj.Get_PrintScale


function TRTOSDemoProj.Get_Scaled: WordBool;

begin // TRTOSDemoProj.Get_Scaled
  Result := Scaled;
end; // TRTOSDemoProj.Get_Scaled


function TRTOSDemoProj.Get_Visible: WordBool;

begin // TRTOSDemoProj.Get_Visible
  Result := Visible;
end; // TRTOSDemoProj.Get_Visible


procedure TRTOSDemoProj._Set_Font(const Value: IFontDisp);

begin // TRTOSDemoProj._Set_Font
  SetOleFont(Font, Value);
end; // TRTOSDemoProj._Set_Font


procedure TRTOSDemoProj.Set_AutoScroll(Value: WordBool);

begin // TRTOSDemoProj.Set_AutoScroll
  AutoScroll := Value;
end; // TRTOSDemoProj.Set_AutoScroll


procedure TRTOSDemoProj.Set_AutoSize(Value: WordBool);

begin // TRTOSDemoProj.Set_AutoSize
  AutoSize := Value;
end; // TRTOSDemoProj.Set_AutoSize


procedure TRTOSDemoProj.Set_AxBorderStyle(Value: TxActiveFormBorderStyle);

begin // TRTOSDemoProj.Set_AxBorderStyle
  AxBorderStyle := TActiveFormBorderStyle(Value);
end; // TRTOSDemoProj.Set_AxBorderStyle


procedure TRTOSDemoProj.Set_BiDiMode(Value: TxBiDiMode);

begin // TRTOSDemoProj.Set_BiDiMode
  BiDiMode := TBiDiMode(Value);
end; // TRTOSDemoProj.Set_BiDiMode


procedure TRTOSDemoProj.Set_Caption(const Value: WideString);

begin // TRTOSDemoProj.Set_Caption
  Caption := TCaption(Value);
end; // TRTOSDemoProj.Set_Caption


procedure TRTOSDemoProj.Set_Color(Value: OLE_COLOR);

begin // TRTOSDemoProj.Set_Color
  Color := TColor(Value);
end; // TRTOSDemoProj.Set_Color


procedure TRTOSDemoProj.Set_Cursor(Value: Smallint);

begin // TRTOSDemoProj.Set_Cursor
  Cursor := TCursor(Value);
end; // TRTOSDemoProj.Set_Cursor


procedure TRTOSDemoProj.Set_DoubleBuffered(Value: WordBool);

begin // TRTOSDemoProj.Set_DoubleBuffered
  DoubleBuffered := Value;
end; // TRTOSDemoProj.Set_DoubleBuffered


procedure TRTOSDemoProj.Set_DropTarget(Value: WordBool);

begin // TRTOSDemoProj.Set_DropTarget
  DropTarget := Value;
end; // TRTOSDemoProj.Set_DropTarget


procedure TRTOSDemoProj.Set_Enabled(Value: WordBool);

begin // TRTOSDemoProj.Set_Enabled
  Enabled := Value;
end; // TRTOSDemoProj.Set_Enabled


procedure TRTOSDemoProj.Set_Font(var Value: IFontDisp);

begin // TRTOSDemoProj.Set_Font
  SetOleFont(Font, Value);
end; // TRTOSDemoProj.Set_Font


procedure TRTOSDemoProj.Set_HelpFile(const Value: WideString);

begin // TRTOSDemoProj.Set_HelpFile
  HelpFile := String(Value);
end; // TRTOSDemoProj.Set_HelpFile


procedure TRTOSDemoProj.Set_KeyPreview(Value: WordBool);

begin // TRTOSDemoProj.Set_KeyPreview
  KeyPreview := Value;
end; // TRTOSDemoProj.Set_KeyPreview


procedure TRTOSDemoProj.Set_PixelsPerInch(Value: Integer);

begin // TRTOSDemoProj.Set_PixelsPerInch
  PixelsPerInch := Value;
end; // TRTOSDemoProj.Set_PixelsPerInch


procedure TRTOSDemoProj.Set_PrintScale(Value: TxPrintScale);

begin // TRTOSDemoProj.Set_PrintScale
  PrintScale := TPrintScale(Value);
end; // TRTOSDemoProj.Set_PrintScale


procedure TRTOSDemoProj.Set_Scaled(Value: WordBool);

begin // TRTOSDemoProj.Set_Scaled
  Scaled := Value;
end; // TRTOSDemoProj.Set_Scaled


procedure TRTOSDemoProj.Set_Visible(Value: WordBool);

begin // TRTOSDemoProj.Set_Visible
  Visible := Value;
end; // TRTOSDemoProj.Set_Visible


procedure TRTOSDemoProj.ActivateEvent(Sender: TObject);

begin // TRTOSDemoProj.ActivateEvent
  if FEvents <> nil then FEvents.OnActivate;
end; // TRTOSDemoProj.ActivateEvent


procedure TRTOSDemoProj.ClickEvent(Sender: TObject);

begin // TRTOSDemoProj.ClickEvent
  if FEvents <> nil then FEvents.OnClick;
end; // TRTOSDemoProj.ClickEvent


procedure TRTOSDemoProj.CreateEvent(Sender: TObject);

begin // TRTOSDemoProj.CreateEvent
  if FEvents <> nil then FEvents.OnCreate;
end; // TRTOSDemoProj.CreateEvent


procedure TRTOSDemoProj.DblClickEvent(Sender: TObject);

begin // TRTOSDemoProj.DblClickEvent
  if FEvents <> nil then FEvents.OnDblClick;
end; // TRTOSDemoProj.DblClickEvent


procedure TRTOSDemoProj.DeactivateEvent(Sender: TObject);

begin // TRTOSDemoProj.DeactivateEvent
  if FEvents <> nil then FEvents.OnDeactivate;
end; // TRTOSDemoProj.DeactivateEvent


procedure TRTOSDemoProj.DestroyEvent(Sender: TObject);

begin // TRTOSDemoProj.DestroyEvent
  if FEvents <> nil then begin
    FEvents.OnDestroy;
  end; // if
end; // TRTOSDemoProj.DestroyEvent


procedure TRTOSDemoProj.KeyPressEvent(Sender: TObject; var Key: Char);

var
  TempKey: Smallint;

begin // TRTOSDemoProj.KeyPressEvent
  TempKey := Smallint(Key);
  if FEvents <> nil then FEvents.OnKeyPress(TempKey);
  Key := Char(TempKey);
end; // TRTOSDemoProj.KeyPressEvent


procedure TRTOSDemoProj.PaintEvent(Sender: TObject);

begin // TRTOSDemoProj.PaintEvent
  if FEvents <> nil then FEvents.OnPaint;
end; // TRTOSDemoProj.PaintEvent


procedure TRTOSDemoProj.GoBClick(Sender: TObject);

begin // TRTOSDemoProj.GoBClick
  if FNertosEvents <> nil then begin
    Log('<= Start');
    FNertosEvents.Start;
  end; // if
end; // TRTOSDemoProj.GoBClick


procedure TRTOSDemoProj.BreakBClick(Sender: TObject);

begin // TRTOSDemoProj.BreakBClick
  if FNertosEvents <> nil then begin
    Log('<= Stop');
    FNertosEvents.Stop;
  end; // if
end; // TRTOSDemoProj.BreakBClick


procedure TRTOSDemoProj.TStartBClick(Sender: TObject);

begin // TRTOSDemoProj.TStartBClick
  if FNertosEvents <> nil then begin
    Log('<= TraceStart');
    FNertosEvents.TraceStart;
  end; // if
end; // TRTOSDemoProj.TStartBClick


procedure TRTOSDemoProj.TStopBClick(Sender: TObject);

begin // TRTOSDemoProj.TStopBClick
  if FNertosEvents <> nil then begin
    Log('<= TraceStop');
    FNertosEvents.TraceStop;
  end; // if
end; // TRTOSDemoProj.TStopBClick


procedure TRTOSDemoProj.LoggingCBClick(Sender: TObject);
begin
  IsLogging := LoggingCB.Checked;
end;

procedure TRTOSDemoProj.ClearLogBClick(Sender: TObject);
begin
  LoggingM.Clear;
end;

initialization
  TRTOSDemoFactory.Create(
    ComServer,
    TActiveFormControl,
    TRTOSDemoProj,
    Class_RTOSDemo,
    1,
    '',
    OLEMISC_SIMPLEFRAME or OLEMISC_ACTSLIKELABEL,
    tmApartment);
end.



